caelestis
=========

|build-status|

Installing ``caelestis`` is easy::

    pip install caelestis

Development
-----------

Increment the version number using ``bump2version``.::

    bump2version [major|minor|patch]

New releases are automatically deployed to PyPI via Travis CI.
Don't forget to push tags: ``git push --tags``.


.. |build-status| image:: https://travis-ci.com/lucasmaystre/caelestis.svg?branch=master
   :alt: build status
   :scale: 100%
   :target: https://travis-ci.com/lucasmaystre/caelestis
